@@ -1,6 +1,5 @@
-""" 
-Contains clases that demonstrate various simple message use cases using a JMS
-Messaging provider, HJB and  py.hjb.  
+"""Contains clases that demonstrate various messaging use cases
+using a JMS Messaging provider, HJB and pyhjb.
 """
 
 from copy import deepcopy
@@ -16,10 +15,14 @@ from hjb.demoutil import *
 
 log = logging.getLogger("hjb.demo")
 
+__docformat__ = "restructuredtext en"
+
 def create_memory_logging_handler(**kw):
-    return UsefulMemoryHandler(5, target_generator=create_file_logging_handler) 
+    """Create a logging handler that buffers logged messages in memory.""" 
+    return PeriodicFlushMemoryHandler(5, target_generator=create_file_logging_handler) 
 
 def create_file_logging_handler(logfile="C:\\Temp\\hjb_debug.log", level=logging.DEBUG):
+    """Create a logging handler that sends logged messages to a file."""
     h = logging.FileHandler(logfile)
     h.setLevel(level)
     f = logging.Formatter('%(asctime)s %(name)-12s %(levelname)-8s %(message)s')
@@ -27,6 +30,7 @@ def create_file_logging_handler(logfile="C:\\Temp\\hjb_debug.log", level=logging
     return h
 
 def create_jms_logging_handler(demo, level=logging.INFO):
+    """Create a logging handler that sends logged messages to a JMS destination.""" 
     dsc = demo.scenario
     logging_scenario = SimpleMessagingScenario(
             HJBClient(
@@ -51,21 +55,27 @@ def create_jms_logging_handler(demo, level=logging.INFO):
 class Demo(object):
     """I provide my subclasses with useful methods for demonstrating HJB's
     capabilities.
+
+    :ivar scenario: an instance's `hjb.hjbclient.SimpleMessagingScenario`
+
+    :ivar aliases: a map used to allow queues and destinations to
+                   referred to by logical names rather than their actual jndi names.
+
+                   
     """
 
     def __init__(self, scenario, aliases):
+        """Initialise the demo.
+        
+        
+        """ 
         self.aliases = aliases
         self.scenario = scenario
         self.use_jms_log = False
 
     def get_producer_aliases(self):
         """Obtain the list of destination aliases that have actually been
-        used as in producers.
-
-        If its present, this will be the value of `self.configured_producers`
-        field, which should have been assigned by `self._create_session_config`.
-
-        Otherwise it will be the value of `self.aliases.keys()`
+        used as producers.
 
         """
         result = getattr(self, 'configured_producers', None)
@@ -92,10 +102,10 @@ class Demo(object):
         Assumes that `self.scenario` has a first session with configured
         producers. 
         
-        Uses `self.aliases` to route message to different producers depending
-        on type of the message or the value of the `hjb_send_to` header in the
-        message when that is present and the destinations available in
-        `self.scenario`.
+        Uses `self.aliases` to route messages to different producers
+        depending on type of the message or the value of the
+        *hjb_send_to* header in the message when that is present and
+        the destinations available in `self.scenario`.
 
         """
         sc = self.scenario
@@ -113,12 +123,9 @@ class Demo(object):
         return compose_url(producers[0], "send")
 
     def create_heartbeat(self, name):
-        """Create a `demoutil.Heartbeat`.
-       
-        Create a `demoutil.Heartbeat` instance that fires heartbeat messages 
-        for this demo instance.
+        """Create a `demoutil.Heartbeat` that fires heartbeat messages.
         
-        Assumes that `self.scenario` has as a first session with a configured
+        Assumes that `self.scenario` has a first session with a configured
         heartbeat producer. 
         
         """ 
@@ -136,7 +143,16 @@ class Demo(object):
         sc = self.scenario
         assert sc, "no scenario supplied"
         assert len(sc.sessions) > 0, "scenario has no sessions"
- 
+
+    def run(self, *args, **kw):
+        """Runs the demo
+
+        This default implementation does nothing.
+
+        """
+        pass
+
+        
 class ShutdownProvider(Demo):
     """I shutdown the JMS objects on the HJB server."""
 
@@ -472,22 +488,29 @@ class ReceiveOneMessage(ReceiveLotsOfMessages):
 class SendAndWaitForConversationResponse(ReceiveLotsOfMessages):
     """I send a message and wait for a response to it.
     
-    This method is designed to be run at the same time as another process
-    running the demo `EchoInConversation`.
+    This method is designed to be run at the same time as another
+    process running the demo `EchoInConversation`.
         
-    The producer selects a message at random from the messages generated by
-    `self.message_generator`, adding a header with a specific value that is
-    known to the receiving demo process (the value of `conversation_id`).
+    The producer selects a message at random those produced by
+    `self.message_generator`, adding a header with a specific value
+    that is known to the receiving demo process (the value of
+    `self.conversation_id`).
         
-    The consumer waits for a message identified by a specific value that is
-    known by both the sending and receiving demos (the conversation_id).
-    This is done by using a JMS message selector expression to 
-    configure the consumer.  The consumer times out if no message is
-    received after waiting for the timeout period.
+    The consumer waits for a message identified by
+    `self.conversation_id`.  This is done by using a JMS message
+    selector expression to configure the consumer.  The consumer times
+    out if no message is received after waiting for the timeout
+    period.
 
-    The producer sends the message, then the consumer waits for a response with
-    same conversation_id, timing out after `time_out` seconds if none is
-    received.
+    The producer sends the message, then the consumer waits for a
+    response with same conversation_id, eventually timing out if none
+    is received.
+
+    :ivar conversation_id: a specific value known by both the sending
+                           and receiving demos.
+
+    :ivar message_generator: a generator that produces HJB encoded JMS
+                             messages.
 
     """
 
@@ -586,13 +609,13 @@ class EchoInConversation(SendAndWaitForConversationResponse):
     """I wait to receive a message and then send a response to it.
          
     This demo is designed to be run at the same time as another process
-    running the `SendMessageThenWaitForResponse` demo.
+    running the `SendAndWaitForConversationResponse` demo.
    
-    The consumer waits for a message identified by a specific value that is
-    known by both the sending and receiving demos (the conversation_id).
-    This is done by using a JMS message selector expression to 
-    configure the consumer.  The consumer times out if no message is
-    received after waiting for the timeout period.
+    The consumer waits for a message identified by
+    `self.conversation_id`.  This is done by using a JMS message
+    selector expression to configure the consumer.  The consumer times
+    out if no message is received after waiting for the timeout
+    period.
 
     On receiving the message, it is sent back to the sender using the
     configured producer with the body unchanged.
@@ -633,7 +656,7 @@ class EchoInConversation(SendAndWaitForConversationResponse):
                 pass 
 
     def create_handler_generator(self, message): 
-        """Create a handler_generator function suitable for by `ReceiveLotsOfMessages.run()`."""
+        """Create a handler_generator function suitable for use by `ReceiveLotsOfMessages.run()`."""
         cid = self.conversation_id
         if cid != message.headers.get("hjb_conversation_id", None):
             print "\r... [**   ERROR   **] bad headers: " +  str(message.headers)
@@ -644,7 +667,7 @@ class EchoInConversation(SendAndWaitForConversationResponse):
             return None
 
         def handle_message():
-            """Create a new message with the same body, and sends to the return destination.
+            """Create a new message with the same body, and send it to the return destination.
             
             The response message has empty headers, apart from :
             - the conversation_id
@@ -671,7 +694,14 @@ class EchoInConversation(SendAndWaitForConversationResponse):
          
 
 class SendLotsOfMessages(SendEachJmsMessageType): 
-    """I periodically send messages to the configured demo destinations.""" 
+    """I periodically send messages to the configured demo destinations.
+
+
+    :ivar message_generator: a generator that produces HJB encoded JMS
+                             messages.
+                             
+
+    """ 
 
     def __init__(
             self, 
