@@ -20,11 +20,10 @@ __all__ = [
     "HJBError",
     "SessionObjects",
     "HJBClient",
-    "SimpleHJBProfile",
+    "SimpleMessagingScenario",
     "main",
 ]
-
-__version__ = "0.6.0"
+__docformat__ = "restructuredtext en"
 
 # regex used to determine if a URI refers to an object is part
 # of a connection
@@ -121,10 +120,10 @@ class SessionObjects(object):
 
     def __init__(self, session_object_responses):
         """
-        `session_object_responses` is the map of {`session_object_type`: [list
-           of responses of that type]}
+        `session_object_responses` is the map of
+        *session_object_type*: [list of responses of that type]
 
-        obtained during invocation of `HJBClient.make_session_objects`
+        obtained during invocation of `HJBClient.create_session`
            
         """
         self._responses = session_object_responses
@@ -297,6 +296,7 @@ class HJBClient(object):
                           method="GET",
                           headers=config.get("headers", {}))
 
+
 class SimpleMessagingScenario(object):
     """
     I represent a typical set of interactions with a HJBServer.
@@ -383,7 +383,7 @@ class SimpleMessagingScenario(object):
 
         Updates an existing JMS session by creating the session object
         specified in `session_config`. `session_config` is a map
-        {`session_object_type`: {object-creation-args}}, where object-creation-args
+        {*session_object_type*: {object-creation-args}}, where object-creation-args
         are the parameters to send in the creation request.
 
         The resulting session objects are appended to this instance's list of
@@ -407,7 +407,7 @@ class SimpleMessagingScenario(object):
         """Create another JMS session.
 
         Creates another JMS session, whose session objects are specified by
-        `session_config`.  `session_config` is a map {`session_object_type`:
+        `session_config`.  `session_config` is a map {*session_object_type*:
         {object-creation-args}}, where object-creation-args are the parameters
         to send in the creation request.
 
@@ -474,8 +474,12 @@ class SimpleMessagingScenario(object):
     def _connection_url(self):
         return self._connection_url
 
+
+
 def main():
     pass
 
+
+
 if __name__ == '__main__':
     main()
